CraftTracker

Struct CraftTracker 

pub struct CraftTracker { /* private fields */ }
This structure keeps track of the current crafting recipe selected and allows lazy update of the crafting recipe. A crafting recipe is based on a 3x3 item grid.

Implementations

Source

impl CraftTracker

pub fn update(&mut self, grid: &[ItemStack; 9])

Update this tracker to track a new 3x3 grid of items.

pub fn consume(&self, grid: &mut [ItemStack; 9])

If there is a selected recipe, consume the recipe items from the given inventory, this inventory should be coherent with the one that selected this recipe through the update method. You need to call the update method again in order to update the tracker for the new inventory.

pub fn recipe(&self) -> Option<ItemStack>

If a crafting recipe is currently selected, return the result item.