JavaRandom

Struct JavaRandom 

pub struct JavaRandom { /* private fields */ }
A pseudo-random number generator ported from the Java standard RNG with additional utility methods better suited for rust.

Implementations

Source

impl JavaRandom

pub fn new(seed: i64) -> JavaRandom

pub fn new_seeded() -> JavaRandom

pub fn new_blank() -> JavaRandom

pub fn set_seed(&mut self, seed: i64)

pub fn get_seed(&self) -> i64

pub fn next_blank(&mut self)

pub fn next_int(&mut self) -> i32

pub fn next_int_bounded(&mut self, bound: i32) -> i32

pub fn next_long(&mut self) -> i64

pub fn next_float(&mut self) -> f32

Get the next pseudo-random single-precision float.

pub fn next_double(&mut self) -> f64

Get the next pseudo-random double-precision float.

pub fn next_gaussian(&mut self) -> f64

Get the next pseudo-random double-precision Gaussian random number.

pub fn next_float_vec(&mut self) -> Vec3

Get the next pseudo-random single-precision float vector, x, y and z. This is not part of the standard Java class.

pub fn next_double_vec(&mut self) -> DVec3

Get the next pseudo-random double-precision float vector, x, y and z. This is not part of the standard Java class.

pub fn next_gaussian_vec(&mut self) -> DVec3

Get the next pseudo-random double-precision double vector, x, y and z, with Gaussian distribution. This is not part of the standard Java class.

pub fn next_choice<T: Copy>(&mut self, items: &[T]) -> T

Randomly pick an item in the given slice. This is not part of the standard Java class.

pub fn next_choice_ref<'a, T>(&mut self, items: &'a [T]) -> &'a T

Randomly pick an item in the given slice and return mutable reference to it. This is not part of the standard Java class.

pub fn next_choice_mut<'a, T>(&mut self, items: &'a mut [T]) -> &'a mut T

Randomly pick an item in the given slice and return mutable reference to it. This is not part of the standard Java class.