pub struct CraftTracker { /* private fields */ }Expand description
This structure keeps track of the current crafting recipe selected and allows lazy update of the crafting recipe. A crafting recipe is based on a 3x3 item grid.
Implementations
Sourceimpl CraftTracker
impl CraftTracker
Sourcepub fn update(&mut self, grid: &[ItemStack; 9])
pub fn update(&mut self, grid: &[ItemStack; 9])
Update this tracker to track a new 3x3 grid of items.
Sourcepub fn consume(&self, grid: &mut [ItemStack; 9])
pub fn consume(&self, grid: &mut [ItemStack; 9])
If there is a selected recipe, consume the recipe items from the given inventory,
this inventory should be coherent with the one that selected this recipe through
the update method. You need to call the update method again in order to update
the tracker for the new inventory.